@@ -269,8 +269,8 @@ static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
         acToolTips = g_strdup_printf ("%s\n"
             "----------------\n"
             "%s\n"
-            "Period (s): %d", poConf->acTitle, poConf->acCmd,
-            poConf->iPeriod_ms / 1000);
+            "Period (s): %.2f", poConf->acTitle, poConf->acCmd,
+            (float)poConf->iPeriod_ms / 1000);
 
     gtk_widget_set_tooltip_markup (GTK_WIDGET (poMonitor->wEventBox),acToolTips);
     g_free (acToolTips);
@@ -537,7 +537,7 @@ static int SetMonitorFont (void *p_pvPlugin)
   font = pango_font_description_from_string(poConf->acFont);
   if (G_LIKELY (font))
   {
-    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpt; font-style: %s; font-weight: %s }",
                           pango_font_description_get_family (font),
                           pango_font_description_get_size (font) / PANGO_SCALE,
                           (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
@@ -727,7 +727,7 @@ static void SetLabel (GtkWidget *p_wTF, void *p_pvPlugin)
     struct param_t *poConf = &(poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
     const char     *acTitle = gtk_entry_get_text (GTK_ENTRY (p_wTF));
-
+    
     g_free (poConf->acTitle);
     poConf->acTitle = g_strdup (acTitle);
     gtk_label_set_text (GTK_LABEL (poMonitor->wTitle), poConf->acTitle);
@@ -852,19 +852,22 @@ static void genmon_create_options (XfcePanelPlugin *plugin,
 
     xfce_panel_plugin_block_menu (plugin);
 
-    dlg = xfce_titled_dialog_new_with_buttons (_("Configuration"),
+    dlg = xfce_titled_dialog_new_with_buttons (_("Generic Monitor"),
         GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
         GTK_DIALOG_DESTROY_WITH_PARENT,
         "gtk-close", GTK_RESPONSE_OK,
         NULL);
 
+    gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
+    gtk_window_set_icon_name (GTK_WINDOW (dlg), "utilities-system-monitor");
+
     g_signal_connect (dlg, "response", G_CALLBACK (genmon_dialog_response),
         poPlugin);
 
-    xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Generic Monitor"));
+    xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Configuration"));
 
-    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER + 6);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER + 4);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+    gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
     gtk_widget_show(vbox);
     gtk_box_pack_start(GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG(dlg))), vbox, 
         TRUE, TRUE, 0);
